#ifndef NT2_INCLUDE_FUNCTIONS_DIVFIX_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_DIVFIX_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/divfix.hpp>

#endif
